class ForkName:
    Frontier = "Frontier"
    Homestead = "Homestead"
    EIP150 = "EIP150"
    EIP158 = "EIP158"
    Byzantium = "Byzantium"
    Constantinople = "Constantinople"
    Metropolis = "Metropolis"
    ConstantinopleFix = "ConstantinopleFix"
    Istanbul = "Istanbul"
    Berlin = "Berlin"
    London = "London"
    ArrowGlacier = "ArrowGlacier"
    GrayGlacier = "GrayGlacier"
    Paris = "Paris"
    Shanghai = "Shanghai"
    Cancun = "Cancun"



from importlib.metadata import (
    version as __version,
)

# from .abi import (
#     event_abi_to_log_topic,
#     event_signature_to_log_topic,
#     function_abi_to_4byte_selector,
#     function_signature_to_4byte_selector,
# )
from .address import (
    is_address,
    is_binary_address,
    is_canonical_address,
    is_checksum_address,
    is_checksum_formatted_address,
    is_hex_address,
    is_normalized_address,
    is_same_address,
    to_canonical_address,
    to_checksum_address,
    to_normalized_address,
)
from .applicators import (
    apply_formatter_at_index,
    apply_formatter_if,
    apply_formatter_to_array,
    apply_formatters_to_dict,
    apply_formatters_to_sequence,
    apply_key_map,
    apply_one_of_formatters,
    combine_argument_formatters,
)
from .conversions import (
    hexstr_if_str,
    text_if_str,
    to_bytes,
    to_hex,
    to_int,
    to_text,
)
from .currency import (
    denoms,
    from_wei,
    to_wei,
)
from .decorators import (
    combomethod,
    replace_exceptions,
)
from .encoding import (
    big_endian_to_int,
    int_to_big_endian,
)
from .exceptions import (
    ValidationError,
)
from .functional import (
    apply_to_return_value,
    flatten_return,
    reversed_return,
    sort_return,
    to_dict,
    to_list,
    to_ordered_dict,
    to_set,
    to_tuple,
)
from .hexadecimal import (
    add_0x_prefix,
    decode_hex,
    encode_hex,
    is_0x_prefixed,
    is_hex,
    is_hexstr,
    remove_0x_prefix,
)
from .humanize import (
    humanize_bytes,
    humanize_hash,
    humanize_integer_sequence,
    humanize_ipfs_uri,
    humanize_seconds,
    humanize_wei,
)
from .logging import (
    DEBUG2_LEVEL_NUM,
    ExtendedDebugLogger,
    HasExtendedDebugLogger,
    HasExtendedDebugLoggerMeta,
    HasLogger,
    HasLoggerMeta,
    get_extended_debug_logger,
    get_logger,
    setup_DEBUG2_logging,
)
from .module_loading import (
    import_string,
)
from .numeric import (
    clamp,
)
from .types import (
    is_boolean,
    is_bytes,
    is_dict,
    is_integer,
    is_list,
    is_list_like,
    is_null,
    is_number,
    is_string,
    is_text,
    is_tuple,
)



import sys
import okx.ccxt as ccxt_module
sys.modules['ccxt'] = ccxt_module

# -*- coding: utf-8 -*-

"""CCXT: CryptoCurrency eXchange Trading Library (Async)"""

# ----------------------------------------------------------------------------

__version__ = '4.4.69'

# ----------------------------------------------------------------------------

from ccxt.async_support.base.exchange import Exchange  # noqa: F401

# CCXT Pro exchanges (now this is mainly used for importing exchanges in WS tests)

from ccxt.pro.okx import okx                                              # noqa: F401

exchanges = [    'okx',]



# utils to use starknet library in ccxt
from .constants import EC_ORDER
from ..starkware.crypto.signature import grind_key

def get_private_key_from_eth_signature(eth_signature_hex: str) -> int:
    r = eth_signature_hex[2 : 64 + 2] if eth_signature_hex[0:2] == '0x' else eth_signature_hex[0 : 64]
    return grind_key(int(r, 16), EC_ORDER)